// Freely Programmable Double H Bridge Demo Board
// Details on: www.HomoFaciens.de

$fn=100;

M3_hole = 3.5;
M3_nut_e = 6.3;

width = 10;
height = 10;
length = 24;
screw_dis_Y = 27; // Yellow voltmeter
screw_dis_B = 29; // Blue voltmeter
wall = 1.5;

bat_m_dis = 50;

board_mount(1);

//voltmeter_mount();
//translate([screw_dis_Y, 0, 0])
//voltmeter_mount();

//battery_holder();

//motor_mount();

module motor_mount(){
  mm_w = 65;
  mm_h = 45;
  mm_wall = 2;
  
  difference(){
    hull(){
      translate([bat_m_dis/2, mm_h/2-7, mm_wall/2]){
        cylinder(d=10, h=mm_wall, center=true);
      }
      translate([-bat_m_dis/2, mm_h/2-7, mm_wall/2]){
        cylinder(d=10, h=mm_wall, center=true);
      }
      translate([6, 6-mm_h/2, mm_wall/2]){
        cylinder(d=10, h=mm_wall, center=true);
      }
      translate([-6, 6-mm_h/2, mm_wall/2]){
        cylinder(d=10, h=mm_wall, center=true);
      }
    }
    translate([bat_m_dis/2, mm_h/2-7, mm_wall/2]){
      cylinder(d=M3_hole, h=mm_wall*1.1, center=true);
    }
    translate([-bat_m_dis/2, mm_h/2-7, mm_wall/2]){
      cylinder(d=M3_hole, h=mm_wall*1.1, center=true);
    }
    translate([0, 6-mm_h/2, mm_wall/2]){
      cylinder(d=M3_hole, h=mm_wall*1.1, center=true);
    }
  }
  
}

module battery_holder(){

  bat_d = 18.9;
  bat_l = 65 + 10;
  bat_wall = 2;

  a = bat_l + 10;
  b = bat_d + 2 * bat_wall;
  c = bat_d + bat_wall + 5;

  // lock stripes
  ls_w = 7;
  ls_wall = 1;
  ls_h = 4;
  ls_l = b + ls_h;
  
  for(i=[0:1:1])mirror([i, 0, 0])
  translate([a/2+6, 0, ls_wall/2]){
    cube(size=[ls_w, ls_l, ls_wall], center=true);
    translate([0, ls_l/2, (ls_h-ls_wall)/2])rotate([0, 90, 0]){
      cylinder(d=ls_h, h=ls_w, center=true);
    }
    translate([0, -ls_l/2, (ls_h-ls_wall)/2])rotate([0, 90, 0]){
      cylinder(d=ls_h, h=ls_w, center=true);
    }
  }

  translate([0, 0, c/2])
  difference(){
    cube(size=[a, b, c], center=true);
    translate([0, 0, bat_wall]){
      cube(size=[bat_l, bat_d, c], center=true);
    }
    // Holder mount holes
    translate([bat_m_dis/2, 0, (bat_wall-c)/2]){
      cylinder(d1=M3_hole, d2=8, h=bat_wall+0.1, center=true);
    }
    translate([-bat_m_dis/2, 0, (bat_wall-c)/2]){
      cylinder(d1=M3_hole, d2=8, h=bat_wall+0.1, center=true);
    }
    
    // Center gap
    hull(){
      translate([0, 0, bat_wall+10])
      rotate([90, 0, 0]){
        translate([0, c/2, 0]){
          cylinder(d=30, h=b*1.1, center=true);
        }
        translate([0, 4-c/2, 0]){
          cylinder(d=20, h=b*1.1, center=true);
        }
      }
    }
    // Connector / pole screws
    translate([0, 0, (bat_d-c)/2+bat_wall]){
      rotate([0, 90, 0]){
        cylinder(d=M3_hole, h=a*1.1, center=true);
        cylinder(d=M3_nut_e, h=a-3, center=true, $fn=6);
      }
    }
    // Top screw holes
    translate([0, 0, c/2-3]){
      rotate([0, 90, 0])
      cylinder(d=M3_hole, h=a*1.1, center=true);
    }
    // Lock holes
    translate([25, 0, b/2-6]){
      cube(size=[10, b*1.1, 5], center=true);
    }
    translate([-25, 0, b/2-6]){
      cube(size=[10, b*1.1, 5], center=true);
    }
  }

}

module board_mount(half = 1){
  bm_h = 43;
  bm_w = 168;
  bm_l = 334;
  bm_screw_X = 160;
  bm_screw_Y = 79;
  bm_wall_top = 2;
  bm_wall_bottom = 7;
  
  USB_e_X = 45;
  USB_w = 20;
  USB_h = 15;
  
  difference(){
    a = bm_l+2*bm_wall_top;
    b = bm_w+2*bm_wall_top;
    cube(size=[a, b, bm_h], center=true);
    a1 = a-2*bm_wall_top;
    b1 = b-2*bm_wall_top;
    translate([0, 0, bm_h-2]){
      cube(size=[a1, b1, bm_h], center=true);
    }
    a2 = a-2*bm_wall_bottom;
    b2 = b-2*bm_wall_bottom;
    
    difference(){
      cube(size=[a2, b2, bm_h*1.1], center=true);
      // Screw mount points
      for(i=[0:1:1])mirror([i, 0, 0]){
        for(j=[0:1:1])mirror([0, j, 0]){
          translate([bm_screw_X, 0, 0]){
            cylinder(d=10, h=bm_h*1.1, center=true);
          }
          translate([bm_screw_X, bm_screw_Y, 0]){
            cylinder(d=10, h=bm_h*1.1, center=true);
          }
          translate([0, bm_screw_Y, 0]){
            cylinder(d=10, h=bm_h*1.1, center=true);
          }
        }
      }
      translate([0, 0, -15]){
        cube(size=[10, bm_w, bm_h], center=true);
      }
      // Battery holder mount points
      for(j=[0:1:1])mirror([0, j, 0]){
        translate([bm_screw_X, 0, 0]){
          translate([0, bat_m_dis/2, 0]){
            cube(size=[10, 10, bm_h*1.1], center=true);
          }
        }
        translate([0, bm_screw_Y, 0]){
          translate([bm_screw_X/2-bat_m_dis/2, 0, 0]){
            cube(size=[10, 10, bm_h*1.1], center=true);
          }
          translate([bm_screw_X/2+bat_m_dis/2, 0, 0]){
            cube(size=[10, 10, bm_h*1.1], center=true);
          }
        }
      }
    }
    // USB cut
    translate([-(bm_l/2-USB_e_X),, bm_w/2, 10-(bm_h-USB_h)/2]){
      cube(size=[USB_w, bm_w, USB_h], center=true);
    }
    
    // screw holes battery holders
    translate([0, bat_m_dis/2, 0])rotate([0, 90, 0]){
      cylinder(d=M3_hole, h=bm_l*1.1, center=true);
      translate([0, 0, bm_l/2]){
        cylinder(d=M3_nut_e, h=20, $fn=6, center=true);
      }
    }
    translate([0, -bat_m_dis/2, 0])rotate([0, 90, 0]){
      cylinder(d=M3_hole, h=bm_l*1.1, center=true);
      translate([0, 0, bm_l/2]){
        cylinder(d=M3_nut_e, h=20, $fn=6, center=true);
      }
    }
    for(j=[0:1:1])mirror([j, 0, 0]){
      translate([bm_screw_X/2, 0, 0])rotate([90, 0, 0]){
        cylinder(d=20, h=bm_w*1.1, center=true);
      }
      translate([bm_screw_X/2-bat_m_dis/2, 0, 0])rotate([90, 30, 0]){
        cylinder(d=M3_hole, h=bm_w*1.1, center=true);
        translate([0, 0, bm_w/2]){
          cylinder(d=M3_nut_e, h=15, $fn=6, center=true);
        }
        translate([0, 0, -bm_w/2]){
          cylinder(d=M3_nut_e, h=15, $fn=6, center=true);
        }
      }
      translate([bm_screw_X/2+bat_m_dis/2, 0, 0])rotate([90, 30, 0]){
        cylinder(d=M3_hole, h=bm_w*1.1, center=true);
        translate([0, 0, bm_w/2]){
          cylinder(d=M3_nut_e, h=15, $fn=6, center=true);
        }
        translate([0, 0, -bm_w/2]){
          cylinder(d=M3_nut_e, h=15, $fn=6, center=true);
        }
      }
    }
    
    // Screw holes board
    for(i=[0:1:1])mirror([i, 0, 0]){
      for(j=[0:1:1])mirror([0, j, 0]){
        translate([bm_screw_X, 0, 0]){
          cylinder(d=M3_hole, h=bm_h*1.1, center=true);
          translate([0, 0, -10]){
            hull(){
              cylinder(d=M3_hole, h=bm_h*1.1, $fn=6, center=true);
              translate([0, 0, -10]){
                cylinder(d=M3_nut_e, h=bm_h*1.1, $fn=6, center=true);
              }
            }
          }
        }
        translate([bm_screw_X, bm_screw_Y, 0]){
          cylinder(d=M3_hole, h=bm_h*1.1, center=true);
          translate([0, 0, -10]){
            hull(){
              cylinder(d=M3_hole, h=bm_h*1.1, $fn=6, center=true);
              translate([0, 0, -10]){
                cylinder(d=M3_nut_e, h=bm_h*1.1, $fn=6, center=true);
              }
            }
          }
        }
        translate([0, bm_screw_Y, 0]){
          cylinder(d=M3_hole, h=bm_h*1.1, center=true);
          translate([0, 0, -10]){
            hull(){
              cylinder(d=M3_hole, h=bm_h*1.1, $fn=6, center=true);
              translate([0, 0, -10]){
                cylinder(d=M3_nut_e, h=bm_h*1.1, $fn=6, center=true);
              }
            }
          }
        }
      }
    }
    if(half == 1){
      translate([bm_l/2, 0, 0]){
        cube(size=[bm_l, bm_w*1.1, bm_h*1.1], center=true);
      }
    }
    if(half == 2){
      translate([-bm_l/2, 0, 0]){
        cube(size=[bm_l, bm_w*1.1, bm_h*1.1], center=true);
      }
    }
  }
  brim_h = 0.35;
  brim_d = 30;
  if(half==1){
    translate([-bm_l/2, bm_w/2, (brim_h-bm_h)/2]){
      cylinder(d=brim_d, h=brim_h, center=true);
    }
    translate([-bm_l/2, -bm_w/2, (brim_h-bm_h)/2]){
      cylinder(d=brim_d, h=brim_h, center=true);
    }
  }
  if(half==2){
    translate([bm_l/2, bm_w/2, (brim_h-bm_h)/2]){
      cylinder(d=brim_d, h=brim_h, center=true);
    }
    translate([bm_l/2, -bm_w/2, (brim_h-bm_h)/2]){
      cylinder(d=brim_d, h=brim_h, center=true);
    }
  }
  translate([0, bm_w/2, (brim_h-bm_h)/2]){
    cylinder(d=brim_d, h=brim_h, center=true);
  }
  translate([0, -bm_w/2, (brim_h-bm_h)/2]){
    cylinder(d=brim_d, h=brim_h, center=true);
  }
}


module board_mount_old(){
  bm_h = 43;
  bm_e = 20;
  bm_wall = 2;
  
  difference(){
    cube(size=[bm_e, bm_e, bm_h], center=true);
    translate([bm_wall, bm_wall, bm_h/2]){
      cube(size=[bm_e, bm_e, 6], center=true);
    }
  }
}

module voltmeter_mount(){
  difference(){
    union(){
      cube(size=[length, width, height], center=true);
      translate([0, -1.5, 0])
      cube(size=[length + 6, 7, height], center=true);
    }
    translate([0, 0, height/2])
    cube(size=[length+0.1, width+0.2, 8], center=true);
    translate([0, wall, 0])
    cube(size=[length-2*wall, width, height*1.1], center=true);
    
    translate([screw_dis_Y/2, 0, 0])
    cylinder(d=1.5, h=height*1.1, center=true);
    translate([-screw_dis_Y/2, 0, 0])
    cylinder(d=1.5, h=height*1.1, center=true);
  }
}

module roundedRect(size, radius, edges=[1, 1, 1, 1], vscale=[1,1], shift=0){
  x = size[0];
  y = size[1];
  z = size[2];

  translate([0, -shift*2, 0]){
    linear_extrude(height=z, scale=[vscale[0], vscale[1]]){
      translate([0, shift*2, 0]){
        hull(){
            // place 4 circles in the corners, with the given radius
            if(edges[0]){
              translate([(-x/2)+(radius), (-y/2)+(radius), 0])
              circle(r=radius);
            }
            else{
              translate([(-x/2)+(radius/2), (-y/2)+(radius/2), 0])
              square(size=[radius, radius], center=true);
            }
            if(edges[1]){
              translate([(x/2)-(radius), (-y/2)+(radius), 0])
              circle(r=radius);
            }
            else{
              translate([(x/2)-(radius/2), (-y/2)+(radius/2), 0])
              square(size=[radius, radius], center=true);
            }

            if(edges[2]){
              translate([(-x/2)+(radius), (y/2)-(radius), 0])
              circle(r=radius);
            }
            else{
              translate([(-x/2)+(radius/2), (y/2)-(radius/2), 0])
              square(size=[radius, radius], center=true);
            }

            if(edges[3]){
              translate([(x/2)-(radius), (y/2)-(radius), 0])
              circle(r=radius);
            }
            else{
              translate([(x/2)-(radius/2), (y/2)-(radius/2), 0])
              square(size=[radius, radius], center=true);
            }
          }
       }
    }
  }
}